#! /usr/bin/python3.11
# -*- coding: utf-8 -*-

# color_list.py
# This file is generated automatically by running tools/create_color_list.py
# This file is part of viewtext

# We use 248 colors derived from an NBS/ISCC list
# (https://people.csail.mit.edu/jaffer/Color/Dictionaries.html#nbs-iscc)
# Here is the copyright notice from NBS:

#                       http://tx4.us/nbs-iscc.htm
#                         NBS/ISCC Color System
#
# Copyright 2003 Voluntocracy.  Permission is granted to copy and
# distribute modified or unmodified versions of this color dictionary
# provided the copyright notice and this permission notice are preserved
# on all copies and the entire such work is distributed under the terms
# of a permission notice identical to this one.
#
# "Pink" and "brown" are used instead of the more logical "pale red" and
# "dark orange".
#
# http://www.anthus.com/Colors/Cent.html by David A. Mundie, converted
# the NBS Centroid colors from Munsell to CIE XYZ, then converted to Mac
# QuickDraw RGB.  The colors were visibly biased towards pink and had
# duplications.
#
# John Foster reconverted supplied Munsell values via Munsell software
# downloaded from www.gretagmacbeth.com <http://www.gretagmacbeth.com>
# directly to RGB, and tried to resolve some duplicates.  Some of these
# don't even look right, because some of the bright colors are on the
# dark fringes with less chroma and are not centered and high up on the
# hue curves.  Many of the original Munsell values (noted) are outside
# the RGB gamut, and have been adjusted to the closest brightest RGB
# value by changing chroma until 0 or 255 is reached in one out of
# bounds RGB component.  Guesses were made in a few cases (noted) where
# the color was still illogical compared to the name.

from collections import namedtuple

Color = namedtuple('Color',
	[
		'hex',
		'rgb',
		'name',
	]
)

Rgb = namedtuple('Rgb',
	[
		'red',
		'green',
		'blue',
	]
)

color_list = (
	Color(hex = '#222222', rgb = Rgb(red = 133, green = 133, blue = 133), name = 'black'),
	Color(hex = '#38152C', rgb = Rgb(red = 220, green =  82, blue = 173), name = 'red-purplish-dark-very'),
	Color(hex = '#3E1D1E', rgb = Rgb(red = 243, green = 114, blue = 118), name = 'brown-reddish-dark'),
	Color(hex = '#002E3B', rgb = Rgb(red =   0, green = 180, blue = 231), name = 'blue-greenish-dark-very'),
	Color(hex = '#1C352D', rgb = Rgb(red = 110, green = 208, blue = 176), name = 'green-dark-very'),
	Color(hex = '#301934', rgb = Rgb(red = 188, green =  98, blue = 204), name = 'purple-dark-very'),
	Color(hex = '#3F1728', rgb = Rgb(red = 247, green =  90, blue = 157), name = 'red-dark-very'),
	Color(hex = '#422518', rgb = Rgb(red = 259, green = 145, blue =  94), name = 'brown-dark'),
	Color(hex = '#252440', rgb = Rgb(red = 145, green = 141, blue = 251), name = 'blue-purplish-dark'),
	Color(hex = '#3B3121', rgb = Rgb(red = 231, green = 192, blue = 129), name = 'brown-olive-dark'),
	Color(hex = '#31362B', rgb = Rgb(red = 192, green = 212, blue = 169), name = 'green-olive-grayish-dark'),
	Color(hex = '#363527', rgb = Rgb(red = 212, green = 208, blue = 153), name = 'olive-grayish-dark'),
	Color(hex = '#2F2140', rgb = Rgb(red = 184, green = 129, blue = 251), name = 'violet-dark'),
	Color(hex = '#56070C', rgb = Rgb(red = 337, green =  27, blue =  47), name = 'brown-reddish-deep'),
	Color(hex = '#3E322C', rgb = Rgb(red = 243, green = 196, blue = 173), name = 'brown-grayish-dark'),
	Color(hex = '#00304E', rgb = Rgb(red =   0, green = 188, blue = 306), name = 'blue-dark'),
	Color(hex = '#00443F', rgb = Rgb(red =   0, green = 267, blue = 247), name = 'green-bluish-deep'),
	Color(hex = '#403D21', rgb = Rgb(red = 251, green = 239, blue = 129), name = 'olive-dark'),
	Color(hex = '#43302E', rgb = Rgb(red = 263, green = 188, blue = 180), name = 'brown-reddish-grayish-dark'),
	Color(hex = '#32174D', rgb = Rgb(red = 196, green =  90, blue = 302), name = 'violet-deep'),
	Color(hex = '#4B3621', rgb = Rgb(red = 294, green = 212, blue = 129), name = 'brown-yellowish-dark'),
	Color(hex = '#5C0923', rgb = Rgb(red = 361, green =  35, blue = 137), name = 'red-deep-very'),
	Color(hex = '#404F00', rgb = Rgb(red = 251, green = 310, blue =   0), name = 'green-olive-strong'),
	Color(hex = '#1B4D3E', rgb = Rgb(red = 106, green = 302, blue = 243), name = 'green-dark'),
	Color(hex = '#401A4C', rgb = Rgb(red = 251, green = 102, blue = 298), name = 'purple-deep-very'),
	Color(hex = '#272458', rgb = Rgb(red = 153, green = 141, blue = 345), name = 'blue-purplish-deep'),
	Color(hex = '#00543D', rgb = Rgb(red =   0, green = 329, blue = 239), name = 'green-deep'),
	Color(hex = '#54133B', rgb = Rgb(red = 329, green =  75, blue = 231), name = 'red-purplish-deep-very'),
	Color(hex = '#004B49', rgb = Rgb(red =   0, green = 294, blue = 286), name = 'green-bluish-dark'),
	Color(hex = '#593319', rgb = Rgb(red = 349, green = 200, blue =  98), name = 'brown-deep'),
	Color(hex = '#483C32', rgb = Rgb(red = 282, green = 235, blue = 196), name = 'brown-yellowish-grayish-dark'),
	Color(hex = '#00622D', rgb = Rgb(red =   0, green = 384, blue = 176), name = 'green-yellowish-deep'),
	Color(hex = '#004958', rgb = Rgb(red =   0, green = 286, blue = 345), name = 'blue-greenish-dark'),
	Color(hex = '#54194E', rgb = Rgb(red = 329, green =  98, blue = 306), name = 'purple-reddish-deep-very'),
	Color(hex = '#36454F', rgb = Rgb(red = 212, green = 271, blue = 310), name = 'blue-grayish-dark'),
	Color(hex = '#3A4B47', rgb = Rgb(red = 227, green = 294, blue = 278), name = 'green-grayish-dark'),
	Color(hex = '#543D3F', rgb = Rgb(red = 329, green = 239, blue = 247), name = 'red-grayish-dark'),
	Color(hex = '#355E3B', rgb = Rgb(red = 208, green = 369, blue = 231), name = 'green-yellowish-dark'),
	Color(hex = '#4A5D23', rgb = Rgb(red = 290, green = 365, blue = 137), name = 'green-olive-moderate'),
	Color(hex = '#00416A', rgb = Rgb(red =   0, green = 255, blue = 416), name = 'blue-deep'),
	Color(hex = '#654522', rgb = Rgb(red = 396, green = 271, blue = 133), name = 'brown-yellowish-deep'),
	Color(hex = '#50404D', rgb = Rgb(red = 314, green = 251, blue = 302), name = 'purple-grayish-dark'),
	Color(hex = '#673147', rgb = Rgb(red = 404, green = 192, blue = 278), name = 'red-purplish-dark'),
	Color(hex = '#722F37', rgb = Rgb(red = 447, green = 184, blue = 216), name = 'red-dark'),
	Color(hex = '#30267A', rgb = Rgb(red = 188, green = 149, blue = 478), name = 'blue-purplish-vivid'),
	Color(hex = '#515744', rgb = Rgb(red = 318, green = 341, blue = 267), name = 'green-olive-grayish'),
	Color(hex = '#5D3954', rgb = Rgb(red = 365, green = 224, blue = 329), name = 'purple-reddish-dark'),
	Color(hex = '#467129', rgb = Rgb(red = 275, green = 443, blue = 161), name = 'green-yellow-deep'),
	Color(hex = '#563C5C', rgb = Rgb(red = 337, green = 235, blue = 361), name = 'purple-dark'),
	Color(hex = '#6C541E', rgb = Rgb(red = 424, green = 329, blue = 118), name = 'brown-olive-moderate'),
	Color(hex = '#665D1E', rgb = Rgb(red = 400, green = 365, blue = 118), name = 'olive-moderate'),
	Color(hex = '#841B2D', rgb = Rgb(red = 518, green = 106, blue = 176), name = 'red-deep'),
	Color(hex = '#5B5842', rgb = Rgb(red = 357, green = 345, blue = 259), name = 'olive-grayish'),
	Color(hex = '#78184A', rgb = Rgb(red = 471, green =  94, blue = 290), name = 'red-purplish-deep'),
	Color(hex = '#57554C', rgb = Rgb(red = 341, green = 333, blue = 298), name = 'gray-olive'),
	Color(hex = '#4E5755', rgb = Rgb(red = 306, green = 341, blue = 333), name = 'gray-greenish-dark'),
	Color(hex = '#5B504F', rgb = Rgb(red = 357, green = 314, blue = 310), name = 'gray-brownish'),
	Color(hex = '#882D17', rgb = Rgb(red = 533, green = 176, blue =  90), name = 'brown-reddish-strong'),
	Color(hex = '#5C504F', rgb = Rgb(red = 361, green = 314, blue = 310), name = 'gray-reddish-dark'),
	Color(hex = '#635147', rgb = Rgb(red = 388, green = 318, blue = 278), name = 'brown-grayish'),
	Color(hex = '#674C47', rgb = Rgb(red = 404, green = 298, blue = 278), name = 'brown-reddish-grayish'),
	Color(hex = '#6F4E37', rgb = Rgb(red = 435, green = 306, blue = 216), name = 'brown-moderate'),
	Color(hex = '#555555', rgb = Rgb(red = 333, green = 333, blue = 333), name = 'gray-dark'),
	Color(hex = '#80461B', rgb = Rgb(red = 502, green = 275, blue = 106), name = 'brown-strong'),
	Color(hex = '#007959', rgb = Rgb(red =   0, green = 475, blue = 349), name = 'green-strong'),
	Color(hex = '#79443B', rgb = Rgb(red = 475, green = 267, blue = 231), name = 'brown-reddish-moderate'),
	Color(hex = '#602F6B', rgb = Rgb(red = 376, green = 184, blue = 420), name = 'purple-deep'),
	Color(hex = '#51585E', rgb = Rgb(red = 318, green = 345, blue = 369), name = 'gray-bluish-dark'),
	Color(hex = '#554C69', rgb = Rgb(red = 333, green = 298, blue = 412), name = 'violet-grayish'),
	Color(hex = '#702963', rgb = Rgb(red = 439, green = 161, blue = 388), name = 'purple-reddish-deep'),
	Color(hex = '#5D555B', rgb = Rgb(red = 365, green = 333, blue = 357), name = 'gray-purplish-dark'),
	Color(hex = '#4C516D', rgb = Rgb(red = 298, green = 318, blue = 427), name = 'blue-purplish-grayish'),
	Color(hex = '#008856', rgb = Rgb(red =   0, green = 533, blue = 337), name = 'green-vivid'),
	Color(hex = '#3B7861', rgb = Rgb(red = 231, green = 471, blue = 380), name = 'green-moderate'),
	Color(hex = '#007A74', rgb = Rgb(red =   0, green = 478, blue = 455), name = 'green-bluish-strong'),
	Color(hex = '#4E5180', rgb = Rgb(red = 306, green = 318, blue = 502), name = 'blue-purplish-moderate'),
	Color(hex = '#317873', rgb = Rgb(red = 192, green = 471, blue = 451), name = 'green-bluish-moderate'),
	Color(hex = '#870074', rgb = Rgb(red = 529, green =   0, blue = 455), name = 'purple-reddish-vivid'),
	Color(hex = '#826644', rgb = Rgb(red = 510, green = 400, blue = 267), name = 'brown-yellowish-moderate'),
	Color(hex = '#604E81', rgb = Rgb(red = 376, green = 306, blue = 506), name = 'violet-moderate'),
	Color(hex = '#44944A', rgb = Rgb(red = 267, green = 580, blue = 290), name = 'green-yellowish-strong'),
	Color(hex = '#536878', rgb = Rgb(red = 325, green = 408, blue = 471), name = 'blue-grayish'),
	Color(hex = '#9E4732', rgb = Rgb(red = 620, green = 278, blue = 196), name = 'orange-reddish-dark'),
	Color(hex = '#5E716A', rgb = Rgb(red = 369, green = 443, blue = 416), name = 'green-grayish'),
	Color(hex = '#AA381E', rgb = Rgb(red = 667, green = 220, blue = 118), name = 'orange-reddish-deep'),
	Color(hex = '#996515', rgb = Rgb(red = 600, green = 396, blue =  82), name = 'brown-yellowish-strong'),
	Color(hex = '#27A64C', rgb = Rgb(red = 153, green = 651, blue = 298), name = 'green-yellowish-vivid'),
	Color(hex = '#367588', rgb = Rgb(red = 212, green = 459, blue = 533), name = 'blue-greenish-moderate'),
	Color(hex = '#007791', rgb = Rgb(red =   0, green = 467, blue = 569), name = 'blue-greenish-strong'),
	Color(hex = '#008882', rgb = Rgb(red =   0, green = 533, blue = 510), name = 'green-bluish-vivid'),
	Color(hex = '#967117', rgb = Rgb(red = 588, green = 443, blue =  90), name = 'brown-olive-light'),
	Color(hex = '#7E6D5A', rgb = Rgb(red = 494, green = 427, blue = 353), name = 'brown-yellowish-grayish'),
	Color(hex = '#867E36', rgb = Rgb(red = 525, green = 494, blue = 212), name = 'olive-light'),
	Color(hex = '#0067A5', rgb = Rgb(red =   0, green = 404, blue = 647), name = 'blue-strong'),
	Color(hex = '#905D5D', rgb = Rgb(red = 565, green = 365, blue = 365), name = 'red-grayish'),
	Color(hex = '#604E97', rgb = Rgb(red = 376, green = 306, blue = 592), name = 'violet-strong'),
	Color(hex = '#436B95', rgb = Rgb(red = 263, green = 420, blue = 584), name = 'blue-moderate'),
	Color(hex = '#BE0032', rgb = Rgb(red = 745, green =   0, blue = 196), name = 'red-vivid'),
	Color(hex = '#796878', rgb = Rgb(red = 475, green = 408, blue = 471), name = 'purple-grayish'),
	Color(hex = '#2E8495', rgb = Rgb(red = 180, green = 518, blue = 584), name = 'blue-greenish-deep'),
	Color(hex = '#836479', rgb = Rgb(red = 514, green = 392, blue = 475), name = 'purple-reddish-grayish'),
	Color(hex = '#915F6D', rgb = Rgb(red = 569, green = 373, blue = 427), name = 'red-purplish-grayish'),
	Color(hex = '#AB4E52', rgb = Rgb(red = 671, green = 306, blue = 322), name = 'red-moderate'),
	Color(hex = '#679267', rgb = Rgb(red = 404, green = 573, blue = 404), name = 'green-yellowish-moderate'),
	Color(hex = '#545AA7', rgb = Rgb(red = 329, green = 353, blue = 655), name = 'blue-purplish-strong'),
	Color(hex = '#7E9F2E', rgb = Rgb(red = 494, green = 624, blue = 180), name = 'green-yellow-strong'),
	Color(hex = '#0085A1', rgb = Rgb(red =   0, green = 522, blue = 631), name = 'blue-greenish-vivid'),
	Color(hex = '#AE6938', rgb = Rgb(red = 682, green = 412, blue = 220), name = 'orange-brownish'),
	Color(hex = '#BC3F4A', rgb = Rgb(red = 737, green = 247, blue = 290), name = 'red-strong'),
	Color(hex = '#9B9400', rgb = Rgb(red = 608, green = 580, blue =   0), name = 'yellow-greenish-deep'),
	Color(hex = '#915C83', rgb = Rgb(red = 569, green = 361, blue = 514), name = 'purple-reddish-moderate'),
	Color(hex = '#BE6516', rgb = Rgb(red = 745, green = 396, blue =  86), name = 'orange-deep'),
	Color(hex = '#A8516E', rgb = Rgb(red = 659, green = 318, blue = 431), name = 'red-purplish-moderate'),
	Color(hex = '#875692', rgb = Rgb(red = 529, green = 337, blue = 573), name = 'purple-strong'),
	Color(hex = '#86608E', rgb = Rgb(red = 525, green = 376, blue = 557), name = 'purple-moderate'),
	Color(hex = '#B3446C', rgb = Rgb(red = 702, green = 267, blue = 424), name = 'red-purplish-strong'),
	Color(hex = '#8C8767', rgb = Rgb(red = 549, green = 529, blue = 404), name = 'olive-grayish-light'),
	Color(hex = '#98943E', rgb = Rgb(red = 596, green = 580, blue = 243), name = 'yellow-greenish-dark'),
	Color(hex = '#00A693', rgb = Rgb(red =   0, green = 651, blue = 576), name = 'green-bluish-brilliant'),
	Color(hex = '#9E4F88', rgb = Rgb(red = 620, green = 310, blue = 533), name = 'purple-reddish-strong'),
	Color(hex = '#AF8D13', rgb = Rgb(red = 686, green = 553, blue =  75), name = 'yellow-deep'),
	Color(hex = '#A67B5B', rgb = Rgb(red = 651, green = 482, blue = 357), name = 'brown-light'),
	Color(hex = '#8A9A5B', rgb = Rgb(red = 541, green = 604, blue = 357), name = 'green-yellow-moderate'),
	Color(hex = '#958070', rgb = Rgb(red = 584, green = 502, blue = 439), name = 'brown-grayish-light'),
	Color(hex = '#8A8776', rgb = Rgb(red = 541, green = 529, blue = 463), name = 'gray-olive-light'),
	Color(hex = '#8E8279', rgb = Rgb(red = 557, green = 510, blue = 475), name = 'gray-brownish-light'),
	Color(hex = '#848482', rgb = Rgb(red = 518, green = 518, blue = 510), name = 'gray-medium'),
	Color(hex = '#7D8984', rgb = Rgb(red = 490, green = 537, blue = 518), name = 'gray-greenish'),
	Color(hex = '#977F73', rgb = Rgb(red = 592, green = 498, blue = 451), name = 'brown-reddish-grayish-light'),
	Color(hex = '#8DB600', rgb = Rgb(red = 553, green = 714, blue =   0), name = 'green-yellow-vivid'),
	Color(hex = '#8F817F', rgb = Rgb(red = 561, green = 506, blue = 498), name = 'gray-reddish'),
	Color(hex = '#81878B', rgb = Rgb(red = 506, green = 529, blue = 545), name = 'gray-bluish'),
	Color(hex = '#B4745E', rgb = Rgb(red = 706, green = 455, blue = 369), name = 'orange-reddish-grayish'),
	Color(hex = '#AB9144', rgb = Rgb(red = 671, green = 569, blue = 267), name = 'yellow-dark'),
	Color(hex = '#3EB489', rgb = Rgb(red = 243, green = 706, blue = 537), name = 'green-brilliant'),
	Color(hex = '#A87C6D', rgb = Rgb(red = 659, green = 486, blue = 427), name = 'brown-reddish-light'),
	Color(hex = '#A18F60', rgb = Rgb(red = 631, green = 561, blue = 376), name = 'yellow-grayish-dark'),
	Color(hex = '#8B8589', rgb = Rgb(red = 545, green = 522, blue = 537), name = 'gray-purplish'),
	Color(hex = '#8F9779', rgb = Rgb(red = 561, green = 592, blue = 475), name = 'green-yellow-grayish'),
	Color(hex = '#C98500', rgb = Rgb(red = 788, green = 522, blue =   0), name = 'yellow-orange-deep'),
	Color(hex = '#BE8A3D', rgb = Rgb(red = 745, green = 541, blue = 239), name = 'yellow-orange-dark'),
	Color(hex = '#CB6D51', rgb = Rgb(red = 796, green = 427, blue = 318), name = 'orange-reddish-moderate'),
	Color(hex = '#E25822', rgb = Rgb(red = 886, green = 345, blue = 133), name = 'orange-reddish-vivid'),
	Color(hex = '#9A4EAE', rgb = Rgb(red = 604, green = 306, blue = 682), name = 'purple-vivid'),
	Color(hex = '#6C79B8', rgb = Rgb(red = 424, green = 475, blue = 722), name = 'blue-purplish-brilliant'),
	Color(hex = '#6AAB8E', rgb = Rgb(red = 416, green = 671, blue = 557), name = 'green-light'),
	Color(hex = '#239EBA', rgb = Rgb(red = 137, green = 620, blue = 729), name = 'blue-greenish-brilliant'),
	Color(hex = '#CE4676', rgb = Rgb(red = 808, green = 275, blue = 463), name = 'red-purplish-vivid'),
	Color(hex = '#7E73B8', rgb = Rgb(red = 494, green = 451, blue = 722), name = 'violet-brilliant'),
	Color(hex = '#00A1C2', rgb = Rgb(red =   0, green = 631, blue = 761), name = 'blue-vivid'),
	Color(hex = '#E66721', rgb = Rgb(red = 902, green = 404, blue = 129), name = 'pink-yellowish-deep'),
	Color(hex = '#AD8884', rgb = Rgb(red = 678, green = 533, blue = 518), name = 'red-grayish-light'),
	Color(hex = '#66ADA4', rgb = Rgb(red = 400, green = 678, blue = 643), name = 'green-bluish-light'),
	Color(hex = '#AF868E', rgb = Rgb(red = 686, green = 525, blue = 557), name = 'red-purplish-grayish-light'),
	Color(hex = '#8C82B6', rgb = Rgb(red = 549, green = 510, blue = 714), name = 'violet-light'),
	Color(hex = '#8DA399', rgb = Rgb(red = 553, green = 639, blue = 600), name = 'green-pale'),
	Color(hex = '#C08081', rgb = Rgb(red = 753, green = 502, blue = 506), name = 'pink-dark'),
	Color(hex = '#C48379', rgb = Rgb(red = 769, green = 514, blue = 475), name = 'pink-yellowish-dark'),
	Color(hex = '#8C92AC', rgb = Rgb(red = 549, green = 573, blue = 675), name = 'blue-purplish-pale'),
	Color(hex = '#AE9B82', rgb = Rgb(red = 682, green = 608, blue = 510), name = 'brown-yellowish-grayish-light'),
	Color(hex = '#4997D0', rgb = Rgb(red = 286, green = 592, blue = 816), name = 'blue-brilliant'),
	Color(hex = '#BEB72E', rgb = Rgb(red = 745, green = 718, blue = 180), name = 'yellow-greenish-strong'),
	Color(hex = '#9065CA', rgb = Rgb(red = 565, green = 396, blue = 792), name = 'violet-vivid'),
	Color(hex = '#C19A6B', rgb = Rgb(red = 757, green = 604, blue = 420), name = 'brown-yellowish-light'),
	Color(hex = '#9690AB', rgb = Rgb(red = 588, green = 565, blue = 671), name = 'violet-pale'),
	Color(hex = '#AA8A9E', rgb = Rgb(red = 667, green = 541, blue = 620), name = 'purple-reddish-pale'),
	Color(hex = '#C17E91', rgb = Rgb(red = 757, green = 494, blue = 569), name = 'pink-purplish-dark'),
	Color(hex = '#B9B459', rgb = Rgb(red = 725, green = 706, blue = 349), name = 'yellow-greenish-moderate'),
	Color(hex = '#66AABC', rgb = Rgb(red = 400, green = 667, blue = 737), name = 'blue-greenish-light'),
	Color(hex = '#D99058', rgb = Rgb(red = 851, green = 565, blue = 345), name = 'orange-moderate'),
	Color(hex = '#8791BF', rgb = Rgb(red = 529, green = 569, blue = 749), name = 'blue-purplish-light'),
	Color(hex = '#F38400', rgb = Rgb(red = 953, green = 518, blue =   0), name = 'orange-vivid'),
	Color(hex = '#83D37D', rgb = Rgb(red = 514, green = 827, blue = 490), name = 'green-yellowish-brilliant'),
	Color(hex = '#91A3B0', rgb = Rgb(red = 569, green = 639, blue = 690), name = 'blue-pale'),
	Color(hex = '#D4AF37', rgb = Rgb(red = 831, green = 686, blue = 216), name = 'yellow-strong'),
	Color(hex = '#B784A7', rgb = Rgb(red = 718, green = 518, blue = 655), name = 'purple-reddish-light'),
	Color(hex = '#C9AE5D', rgb = Rgb(red = 788, green = 682, blue = 365), name = 'yellow-moderate'),
	Color(hex = '#E4717A', rgb = Rgb(red = 894, green = 443, blue = 478), name = 'pink-deep'),
	Color(hex = '#AA98A9', rgb = Rgb(red = 667, green = 596, blue = 663), name = 'purple-pale'),
	Color(hex = '#70A3CC', rgb = Rgb(red = 439, green = 639, blue = 800), name = 'blue-light'),
	Color(hex = '#93C592', rgb = Rgb(red = 576, green = 773, blue = 573), name = 'green-yellowish-light'),
	Color(hex = '#EAA221', rgb = Rgb(red = 918, green = 635, blue = 129), name = 'yellow-orange-strong'),
	Color(hex = '#B9B57D', rgb = Rgb(red = 725, green = 710, blue = 490), name = 'yellow-greenish-grayish'),
	Color(hex = '#C2B280', rgb = Rgb(red = 761, green = 698, blue = 502), name = 'yellow-grayish'),
	Color(hex = '#E3A857', rgb = Rgb(red = 890, green = 659, blue = 341), name = 'yellow-orange-moderate'),
	Color(hex = '#DE6FA1', rgb = Rgb(red = 871, green = 435, blue = 631), name = 'pink-purplish-deep'),
	Color(hex = '#F6A600', rgb = Rgb(red = 965, green = 651, blue =   0), name = 'yellow-orange-vivid'),
	Color(hex = '#FD943F', rgb = Rgb(red = 992, green = 580, blue = 247), name = 'orange-brilliant'),
	Color(hex = '#C2AC99', rgb = Rgb(red = 761, green = 675, blue = 600), name = 'pink-brownish'),
	Color(hex = '#BDDA57', rgb = Rgb(red = 741, green = 855, blue = 341), name = 'green-yellow-brilliant'),
	Color(hex = '#B695C0', rgb = Rgb(red = 714, green = 584, blue = 753), name = 'purple-light'),
	Color(hex = '#DCD300', rgb = Rgb(red = 863, green = 827, blue =   0), name = 'yellow-greenish-vivid'),
	Color(hex = '#8ED1B2', rgb = Rgb(red = 557, green = 820, blue = 698), name = 'green-light-very'),
	Color(hex = '#C7ADA3', rgb = Rgb(red = 780, green = 678, blue = 639), name = 'pink-yellowish-grayish'),
	Color(hex = '#C3A6B1', rgb = Rgb(red = 765, green = 651, blue = 694), name = 'pink-purplish-grayish'),
	Color(hex = '#F3C300', rgb = Rgb(red = 953, green = 765, blue =   0), name = 'yellow-vivid'),
	Color(hex = '#BFB8A5', rgb = Rgb(red = 749, green = 722, blue = 647), name = 'gray-yellowish'),
	Color(hex = '#F99379', rgb = Rgb(red = 976, green = 576, blue = 475), name = 'pink-yellowish-strong'),
	Color(hex = '#D597AE', rgb = Rgb(red = 835, green = 592, blue = 682), name = 'pink-purplish-moderate'),
	Color(hex = '#C4AEAD', rgb = Rgb(red = 769, green = 682, blue = 678), name = 'pink-grayish'),
	Color(hex = '#EA9399', rgb = Rgb(red = 918, green = 576, blue = 600), name = 'pink-strong'),
	Color(hex = '#B2BEB5', rgb = Rgb(red = 698, green = 745, blue = 710), name = 'gray-greenish-light'),
	Color(hex = '#B9B8B5', rgb = Rgb(red = 725, green = 722, blue = 710), name = 'gray-light'),
	Color(hex = '#E68FAC', rgb = Rgb(red = 902, green = 561, blue = 675), name = 'pink-purplish-strong'),
	Color(hex = '#D9A6A9', rgb = Rgb(red = 851, green = 651, blue = 663), name = 'pink-yellowish-moderate'),
	Color(hex = '#DEA5A4', rgb = Rgb(red = 871, green = 647, blue = 643), name = 'pink-moderate'),
	Color(hex = '#B4BCC0', rgb = Rgb(red = 706, green = 737, blue = 753), name = 'gray-bluish-light'),
	Color(hex = '#BFB9BD', rgb = Rgb(red = 749, green = 725, blue = 741), name = 'gray-purplish-light'),
	Color(hex = '#C9DC89', rgb = Rgb(red = 788, green = 863, blue = 537), name = 'green-yellow-light'),
	Color(hex = '#FFC14F', rgb = Rgb(red = 1000, green = 757, blue = 310), name = 'yellow-orange-brilliant'),
	Color(hex = '#FAB57F', rgb = Rgb(red = 980, green = 710, blue = 498), name = 'orange-light'),
	Color(hex = '#E9E450', rgb = Rgb(red = 914, green = 894, blue = 314), name = 'yellow-greenish-brilliant'),
	Color(hex = '#96DED1', rgb = Rgb(red = 588, green = 871, blue = 820), name = 'green-bluish-light-very'),
	Color(hex = '#B6E5AF', rgb = Rgb(red = 714, green = 898, blue = 686), name = 'green-yellowish-light-very'),
	Color(hex = '#9CD1DC', rgb = Rgb(red = 612, green = 820, blue = 863), name = 'blue-greenish-light-very'),
	Color(hex = '#B3BCE2', rgb = Rgb(red = 702, green = 737, blue = 886), name = 'blue-purplish-light-very'),
	Color(hex = '#FADA5E', rgb = Rgb(red = 980, green = 855, blue = 369), name = 'yellow-brilliant'),
	Color(hex = '#FBC97F', rgb = Rgb(red = 984, green = 788, blue = 498), name = 'yellow-orange-light'),
	Color(hex = '#D399E6', rgb = Rgb(red = 827, green = 600, blue = 902), name = 'purple-brilliant'),
	Color(hex = '#EAE679', rgb = Rgb(red = 918, green = 902, blue = 475), name = 'yellow-greenish-light'),
	Color(hex = '#A1CAF1', rgb = Rgb(red = 631, green = 792, blue = 945), name = 'blue-light-very'),
	Color(hex = '#C4C3DD', rgb = Rgb(red = 769, green = 765, blue = 867), name = 'violet-pale-very'),
	Color(hex = '#FFB7A5', rgb = Rgb(red = 1000, green = 718, blue = 647), name = 'pink-yellowish-vivid'),
	Color(hex = '#F8DE7E', rgb = Rgb(red = 973, green = 871, blue = 494), name = 'yellow-light'),
	Color(hex = '#C0C8E1', rgb = Rgb(red = 753, green = 784, blue = 882), name = 'blue-purplish-pale-very'),
	Color(hex = '#D5BADB', rgb = Rgb(red = 835, green = 729, blue = 859), name = 'purple-light-very'),
	Color(hex = '#DADFB7', rgb = Rgb(red = 855, green = 875, blue = 718), name = 'green-yellow-pale'),
	Color(hex = '#FFB5BA', rgb = Rgb(red = 1000, green = 710, blue = 729), name = 'pink-vivid'),
	Color(hex = '#BCD4E6', rgb = Rgb(red = 737, green = 831, blue = 902), name = 'blue-pale-very'),
	Color(hex = '#EFBBCC', rgb = Rgb(red = 937, green = 733, blue = 800), name = 'pink-purplish-light'),
	Color(hex = '#F4C2C2', rgb = Rgb(red = 957, green = 761, blue = 761), name = 'pink-yellowish-light'),
	Color(hex = '#D6CADD', rgb = Rgb(red = 839, green = 792, blue = 867), name = 'purple-pale-very'),
	Color(hex = '#FAD6A5', rgb = Rgb(red = 980, green = 839, blue = 647), name = 'yellow-orange-pale'),
	Color(hex = '#EBE8A4', rgb = Rgb(red = 922, green = 910, blue = 643), name = 'yellow-greenish-pale'),
	Color(hex = '#C7E6D7', rgb = Rgb(red = 780, green = 902, blue = 843), name = 'green-pale-very'),
	Color(hex = '#ECD5C5', rgb = Rgb(red = 925, green = 835, blue = 773), name = 'pink-yellowish-pale'),
	Color(hex = '#F3E5AB', rgb = Rgb(red = 953, green = 898, blue = 671), name = 'yellow-pale'),
	Color(hex = '#E8CCD7', rgb = Rgb(red = 910, green = 800, blue = 843), name = 'pink-purplish-pale'),
	Color(hex = '#F9CCCA', rgb = Rgb(red = 976, green = 800, blue = 792), name = 'pink-light'),
	Color(hex = '#EAD8D7', rgb = Rgb(red = 918, green = 847, blue = 843), name = 'pink-pale'),
	Color(hex = '#FFC8D6', rgb = Rgb(red = 1000, green = 784, blue = 839), name = 'pink-purplish-brilliant'),
	Color(hex = '#DCD0FF', rgb = Rgb(red = 863, green = 816, blue = 1000), name = 'violet-light-very'),
	Color(hex = '#EAE3E1', rgb = Rgb(red = 918, green = 890, blue = 882), name = 'white-pinkish'),
	Color(hex = '#E8E3E5', rgb = Rgb(red = 910, green = 890, blue = 898), name = 'white-purplish'),
	Color(hex = '#F0EAD6', rgb = Rgb(red = 941, green = 918, blue = 839), name = 'white-yellowish'),
	Color(hex = '#DFEDE8', rgb = Rgb(red = 875, green = 929, blue = 910), name = 'white-greenish'),
	Color(hex = '#E9E9ED', rgb = Rgb(red = 914, green = 914, blue = 929), name = 'white-bluish'),
	Color(hex = '#F2F3F4', rgb = Rgb(red = 949, green = 953, blue = 957), name = 'white'),
)
